<?php

/**
 * The template for displaying Comments.
 * -------------------------------------------------
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to a different function.
 * -------------------------------------------------
 * @author akshitsethi
 * -------------------------------------------------
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

if ( post_password_required() ) {
    return;
}

?>

<div id="comments" class="comments-area">
    <div class="comments-wrapper">
        <?php if ( have_comments() ) : ?>

            <h3 class="comments-title">
                <span><?php printf( _n( 'One Comment', '%1$s Comments', get_comments_number(), 'moscow' ), number_format_i18n( get_comments_number() ) ); ?></span>
            </h3>

            <ol class="comment-list">
                <?php

                    /* Loop through and list the comments. Tell wp_list_comments()
                     * to use shape_comment() to format the comments.
                     * If you want to overload this in a child theme then you can
                     * define shape_comment() and that will be used instead.
                     * See shape_comment() in inc/template-tags.php for more.
                     * -------------------------------------------------
                     */

                    wp_list_comments( array( 'callback' => 'moscow_wp_comments' ) );

                ?>
            </ol><!-- .commentlist -->

            <?php

                // Comment Navigation
                // -------------------------------------------------

                if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :

            ?>

                <nav id="comment-nav-below" class="comment-navigation">
                    <div class="nav-links">
                        <div class="nav-previous">
                            <?php previous_comments_link( '<i class="fa fa-3x fa-angle-left"></i>' ); ?>
                        </div>

                        <div class="nav-next">
                            <?php next_comments_link( '<i class="fa fa-3x fa-angle-right"></i>' ); ?>
                        </div>
                    </div><!-- .nav-links -->
                </nav><!-- #comment-nav-below -->

            <?php endif; // check for comment navigation. ?>
        <?php endif; // have_comments() ?>
        <?php

            if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :

        ?>

            <p class="no-comments"><?php esc_html_e( 'Comments are closed', 'moscow' ); ?></p><!-- .no-comments -->

        <?php endif; // comments_open() ?>
    </div><!-- .comments-wrapper -->

    <div class="respond-area">
        <?php

            /**
             * Including file for the comment_form()
             * We have customized the form to match the theme style.
             * -------------------------------------------------
             */

            require AS_THEME_PATH . '/framework/include/comment-form.php';

        ?>
    </div><!-- .respond-area -->
</div><!-- .comments-area -->