<?php

/**
 * Custom functions that act independently of the theme templates.
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @author akshitsethi
 * 

moscow_page_menu_args()
moscow_wp_title()
moscow_setup_author()
moscow_password_form()
moscow_tag_cloud()
moscow_wp_contacts()
moscow_post_thumbnail()
moscow_post_title()
moscow_post_link()
moscow_post_content()
moscow_single_title()
moscow_link_pages()
moscow_edit_link()
moscow_post_links()
moscow_image_links()
moscow_wp_logo()
moscow_excerpt_long_length()
moscow_excerpt_short_length()
moscow_excerpt_more()
moscow_read_more()
moscow_wrapper()
moscow_container()
moscow_full_size_gallery()

 *
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 * @param array $args Configuration arguments.
 * @return array
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_page_menu_args' ) ) :
function moscow_page_menu_args( $args ) {

	$args['show_home'] = true;
	return $args;

}
add_filter( 'wp_page_menu_args', 'moscow_page_menu_args' );
endif;


/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @param string $title Default title text for current view.
 * @param string $sep Optional separator.
 * @return string The filtered title.
 * -------------------------------------------------
 */

if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
function moscow_wp_title( $title, $sep ) {

	if ( is_feed() ) {
		return $title;
	}

	global $page, $paged;

	// Blog Name
	// -------------------------------------------------

	$title .= get_bloginfo( 'name', 'display' );

	// Description
	// -------------------------------------------------

	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title .= " $sep $site_description";
	}

	// Page Number
	// -------------------------------------------------

	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title .= " $sep " . sprintf( esc_html__( 'Page %s', 'moscow' ), max( $paged, $page ) );
	}

	return $title;

}
add_filter( 'wp_title', 'moscow_wp_title', 10, 2 );
endif;


/**
 * Sets the authordata global when viewing an author archive.
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_setup_author' ) ) :
function moscow_setup_author() {

	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}

}
add_action( 'wp', 'moscow_setup_author' );
endif;


/**
 * Adding custom styles to the post password form.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_password_form' ) ) :
function moscow_password_form() {

	global $post;

	$label 	= 'pwbox-' . ( empty( $post->ID ) ? rand() : $post->ID );
	$o 		= '<p>' . esc_html__( 'To view this protected post, enter the password below:', 'moscow' ) . '</p>';
	$o 		.= '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="postpass-form" method="post"><div class="form-group"><input name="post_password" id="' . $label . '" type="password" class="s-form-control" maxlength="20" /></div><input type="submit" name="Submit" value="' . esc_attr__( 'Submit', 'moscow' ) . '" class="button" /></form>';

	return $o;

}
add_filter( 'the_password_form', 'moscow_password_form' );
endif;


/**
 * Customizing the WP tag cloud widget.
 * Removing different inline font sizes.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_tag_cloud' ) ) :
function moscow_tag_cloud( $tag_string ) {

	return preg_replace( "/style='font-size:.+pt;'/", '', $tag_string );

}
add_filter( 'wp_tag_cloud', 'moscow_tag_cloud' );
endif;


/**
 * Function to add user social networks option in the profile page.
 * Works beautifully with the theme.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_wp_contacts' ) ) :
function moscow_wp_contacts( $args ) {

	// add Twitter, Facebook, LinkedIn, Google+, Instagram, and Youtube
	$args['twitter'] 		= esc_html__( 'Twitter', 'moscow' );
	$args['facebook'] 		= esc_html__( 'Facebook', 'moscow' );
	$args['linked_in'] 		= esc_html__( 'LinkedIn', 'moscow' );
	$args['google_plus'] 	= esc_html__( 'Google+', 'moscow' );
	$args['instagram'] 		= esc_html__( 'Instagram', 'moscow' );
	$args['youtube'] 		= esc_html__( 'Youtube', 'moscow' );

	return $args;

}
add_filter( 'user_contactmethods', 'moscow_wp_contacts', 10, 1 );
endif;


/**
 * Post thumbail option.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_thumbnail' ) ) :
function moscow_post_thumbnail( $size, $blog = 'square' ) {

	global $post;

	$format = get_post_format( $post->ID ) ? : 'standard';

	if ( has_post_thumbnail() ) {
		if ( '1-col' == $blog ) {
			$background = get_the_post_thumbnail_url( $post->ID, 'full' );

			echo '<div class="entry-featured-image ' . $format . '-icon" style="background-image: url(\'' . $background . '\');">';
			echo '</div><!-- .entry-featured-image -->';
		} else {
			echo '<div class="entry-featured-image ' . $format . '-icon">';
			echo '<a href="' . get_the_permalink( $post->ID ) . '" title="' . esc_attr( get_the_title( $post->ID ) ) . '">';

			the_post_thumbnail( $size, array( 'alt' => get_the_title() ) );

			echo '</a>';
			echo '</div><!-- .entry-featured-image -->';
		}
	}

}
endif;


/**
 * Post title (with & without link).
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_title' ) ) :
function moscow_post_title( $span = false, $echo = true ) {

	if ( $span ) {
		if ( $echo ) {
			echo the_title( '<h1 class="entry-title"><span>', '</span></h1>', false );
		} else {
			return the_title( '<h1 class="entry-title"><span>', '</span></h1>', false );
		}
	} else {
		if ( $echo ) {
			echo the_title( '<h1 class="entry-title">', '</h1>', false );
		} else {
			return the_title( '<h1 class="entry-title">', '</h1>', false );
		}
	}

}
endif;


if ( ! function_exists( 'moscow_post_title_link' ) ) :
function moscow_post_title_link( $span = false, $echo = true ) {

	if ( $span ) {
		if ( $echo ) {
			echo the_title( sprintf( '<h2 class="entry-title"><span><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></span></h2>', false );
		} else {
			return the_title( sprintf( '<h2 class="entry-title"><span><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></span></h2>', false );
		}
	} else {
		if ( $echo ) {
			echo the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>', false );
		} else {
			return the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>', false );
		}
	}

}
endif;


/**
 * Post content.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_content' ) ) :
function moscow_post_content( $blog = false ) {

	// Content or Excerpt
	// -------------------------------------------------

	if ( is_home() || is_archive() || is_search() || is_author() || $blog ) {
		if ( 'classic' == $blog ) {
			the_content( esc_html__( 'Continue Reading', 'moscow' ) . ' &nbsp;<span>&rarr;</span>' );
		} else {
			the_excerpt();
		}
	} elseif ( is_single() || is_page() ) {
		if ( 'classic' == $blog ) {
			the_content();
		} else {
			the_excerpt();
		}
	} else {
		the_excerpt();
	}

}
endif;


/**
 * Single post title and meta.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_single_title' ) ) :
function moscow_single_title() {

	echo '<header class="entry-header">';

	// Title
	// -------------------------------------------------

	moscow_post_title();

	// Meta
	// -------------------------------------------------

	if ( ! get_theme_mod( 'blog_meta' ) ) {
		echo '<div class="entry-meta">';

		// Show
		moscow_post_meta();

		echo '</div><!-- .entry-meta -->';
	}

	echo '</header><!-- .entry-header -->';

}
endif;


/**
 * WP Link pages.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_link_pages' ) ) :
function moscow_link_pages() {

	// Navigation : Linked Post Pages
	wp_link_pages( array(
		'before' 		=> '<div class="page-links">' . esc_html__( 'Pages', 'moscow' ),
		'after'  		=> '</div>',
		'link_before' 	=> '<span>',
		'link_after' 	=> '</span>'
	) );

}
endif;


/**
 * Edit link for post and pages.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_edit_link' ) ) :
function moscow_edit_link() {

	edit_post_link( esc_html__( 'Edit Post', 'moscow' ), '<div class="edit-link">', '</div>' );

}
endif;


/**
 * Navigation links for the previous & next posts.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_post_links' ) ) :
function moscow_post_links() {

?>

	<nav class="single-post-navigation">
		<div class="nav-links">
			<?php

				// Previous Post
				// -------------------------------------------------

				previous_post_link( '<div class="nav-previous">' . esc_html__( 'Previous Post', 'moscow' ) . ' <span>%link</span></div><!-- .nav-previous -->', esc_html__( '%title', 'moscow' ) );

				// Next Post
				// -------------------------------------------------

				next_post_link( '<div class="nav-next">' . esc_html__( 'Next Post', 'moscow' ) . ' <span>%link</span></div><!-- .nav-next -->', esc_html__( '%title', 'moscow' ) );

			?>
		</div><!-- .nav-links -->
	</nav><!-- .single-post-navigation -->

<?php

}
endif;


/**
 * Navigation links on the image attachment page.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_image_links' ) ) :
function moscow_image_links() {

?>

	<nav class="navigation image-navigation">
		<div class="nav-links">
			<div class="nav-previous">
				<?php previous_image_link( array( 150, 150 ) ); ?>
			</div><!-- .nav-previous -->

			<div class="nav-next">
				<?php next_image_link( array( 150, 150 ) ); ?>
			</div><!-- .nav-next -->
		</div><!-- .nav-links -->
	</nav><!-- .image-navigation -->

<?php

}
endif;


/**
 * Logo for the header section of the theme.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_wp_logo' ) ) :
function moscow_wp_logo() {

	if ( get_theme_mod( 'logo' ) ) {

?>

		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
			<img src="<?php echo esc_url( get_theme_mod( 'logo' ) ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" class="logo" />
		</a>

<?php

	} else {

?>

		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
			<img src="<?php echo AS_THEME_URL; ?>/framework/img/logo.png" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" class="logo" />
		</a>

<?php

	}

}
endif;


/**
 * Strip down the excerpt length of posts.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_excerpt_long_length' ) ) :
function moscow_excerpt_long_length( $length ) {

	return 30;

}
endif;


// Short
// -------------------------------------------------

if ( ! function_exists( 'moscow_excerpt_short_length' ) ) :
function moscow_excerpt_short_length( $length ) {

	return 14;

}
endif;


/**
 * Replace the "more" text of a post excerpt.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_excerpt_more' ) ) :
function moscow_excerpt_more( $more ) {

	return '&hellip;';

}
add_filter( 'excerpt_more', 'moscow_excerpt_more' );
endif;


/**
 * Add <div> wrapper to read more link.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_read_more' ) ) :
function moscow_read_more( $input ) {

	return '<div class="read-more">' . $input . '</div>';

}
add_filter( 'the_content_more_link', 'moscow_read_more' );
endif;


/**
 * Functions for the Posts & Container wrappers.
 * -------------------------------------------------
 * Adds a <div> wrapper for the posts.
 */

if ( ! function_exists( 'moscow_wrapper' ) ) :
function moscow_wrapper( $end = false ) {

	if ( $end ) {
		echo '</div><!-- .posts-wrapper -->';
	} else {
		if ( get_theme_mod( 'blog_header' ) ) {
			if ( is_home() || is_front_page() ) {
				echo '<div class="as-blog-header">';
				echo '<h2 class="as-featured-header"><span>' . esc_html( get_theme_mod( 'blog_header_title', __( 'Blog', 'moscow' ) ) ) . '</span></h2>';
				echo '<p class="as-lead">' . esc_html( get_theme_mod( 'blog_header_description', __( 'News trending this week..', 'moscow' ) ) ) . '</p>';
				echo '</div><!-- .as-blog-header -->';
			}
		}

		echo '<div class="posts-wrapper">';
	}

}
endif;


// Container
// -------------------------------------------------

if ( ! function_exists( 'moscow_container' ) ) :
function moscow_container( $end = false, $class = '' ) {

	if ( $end ) {
		echo '</div><!-- .row -->';
	} else {
		if ( ! empty( $class ) ) {
			echo '<div class="row ' . $class . '">';
		} else {
			echo '<div class="row">';
		}
	}

}
endif;


// Gallery (Full)
// -------------------------------------------------

if ( ! function_exists( 'moscow_full_size_gallery' ) ) :
function moscow_full_size_gallery( $out ) {

	remove_filter( current_filter(), __FUNCTION__ );
    $out['size'] = 'full';

    return $out;

}
add_filter( 'get_post_gallery', 'moscow_full_size_gallery', 10, 3 );
endif;