<?php

/**
 * Setup for the theme.
 *
 * @author akshitsethi
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


// Set the content width based on the theme's design and stylesheet.
// -------------------------------------------------

if ( ! isset( $content_width ) ) {
	$content_width = 1170; // pixels
}


/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 * -------------------------------------------------
 */

if ( ! function_exists( 'moscow_theme_setup' ) ) :
function moscow_theme_setup() {

	/**
	 * Theme is translation ready.
	 * Translations can be filed in the framework/langs/ directory.
	 * -------------------------------------------------
	 */

	load_theme_textdomain( 'moscow', get_template_directory() . '/framework/langs' );


	/**
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 * -------------------------------------------------
	 */

	add_theme_support( 'title-tag' );


	/**
	 * This theme uses wp_nav_menu() in one location.
	 * -------------------------------------------------
	 */

	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'moscow' )
	) );


	/**
	 * 1. Switch default core markup for search form, comment form, and comments to output valid HTML5.
	 * 2. Add default posts and comments RSS feed links to head.
	 * 3. Enable support for Post Formats.
	 * 4. Enable support for Post Thumbnails on posts and pages.
	 * 5. Enable support for Custom Background.
	 * -------------------------------------------------
	 */

	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) ); // 1
	add_theme_support( 'automatic-feed-links' ); // 2
	add_theme_support( 'post-formats', array( 'gallery', 'audio', 'video' ) ); // 3
	add_theme_support( 'post-thumbnails', array( 'post' ) ); // 4
	add_theme_support( 'custom-background', apply_filters( 'moscow_custom_background_args', array( 'default-color' => 'ffffff', 'default-image' => '' ) ) ); // 5


	/**
	 * Media sizes (images) required by the theme.
	 * -------------------------------------------------
	 */

	add_image_size( 'moscow-medium', 600, 400, true );
	add_image_size( 'moscow-square', 600, 600, true );
	add_image_size( 'moscow-long', 400, 700, true );
	add_image_size( 'moscow-full', 1200, 9999, false );


	/**
	 * Adding editor style support.
	 * -------------------------------------------------
	 */

	$moscow_editor_fonts = add_query_arg( 'family', urlencode( 'Heebo:400,500,700|Lora:400,400i,700,700i&subset=latin-ext' ), '//fonts.googleapis.com/css' );

	add_editor_style( $moscow_editor_fonts );
	add_editor_style( 'framework/css/editor.css' );

}
add_action( 'after_setup_theme', 'moscow_theme_setup' );
endif;