<?php

/**
 * View: Instagram
 *
 * @author akshitsethi
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( get_theme_mod( 'instagram_username' ) ) :
	echo '<div class="as-instagram">';
	echo '<div class="row column">';
		echo '<h4><span>' . esc_html( get_theme_mod( 'instagram_title', __( 'I\'m on Instagram', 'moscow' ) ) ) . '</span></h4>';
	echo '</div><!-- .row -->';

	// Username Check
	$moscow_instagram_user 	= esc_html( get_theme_mod( 'instagram_username' ) );
	$moscow_instagram_limit = intval( get_theme_mod( 'instagram_photos', '10' ) );

	if ( isset( $moscow_instagram_user ) && '' != $moscow_instagram_user ) {
		$moscow_instagram_media = moscow_instagram_feed( $moscow_instagram_user, $moscow_instagram_limit );

		// If the scraping process contained errors
		if ( is_wp_error( $moscow_instagram_media ) ) {
			echo '<div class="row column">';
			echo '<p class="instagram-error"><span>' . $moscow_instagram_media->get_error_message() . '</span></p>';
			echo '</div><!-- .row -->';
		} else {
			if ( is_array( $moscow_instagram_media ) && ! empty( $moscow_instagram_media ) ) {
				echo '<div class="instagram-container">';

				foreach ( $moscow_instagram_media as $moscow_instagram_count => $moscow_instagram_item ) {
					if ( $moscow_instagram_count >= $moscow_instagram_limit ) {
						break;
					}

					echo '<div class="as-instagram-slide" style="background-image: url(' . esc_url( $moscow_instagram_item['url_medium'] ) . ');"><a href="' . esc_url( $moscow_instagram_item['link'] ) . '" target="_blank"></a></div>';
				}

				echo '</div><!-- .instagram-container -->';
			}
		}
	}

	echo '</div><!-- .as-instagram -->';
endif;


/**
 * For scraping the instagram feed
 * @link https://gist.github.com/cosmocatalano/4544576
 */

function moscow_instagram_feed( $username, $slice = 10 ) {

	$username 		= strtolower( $username );
	$option_name 	= 'moscow_instagram_' . $username;
	$instaData 		= get_transient( $option_name );

	if ( false ===  $instaData ) {
		$response = wp_remote_get( 'http://instagram.com/' . trim( $username ), array( 'sslverify' => false, 'timeout' => 60, 'user-agent' => 'Akshit-Sethi' ) );

		if ( is_wp_error( $response ) ) {
			return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'moscow' ) );
		}

		if ( 200 == $response['response']['code'] ) {
			$json = str_replace( 'window._sharedData = ', '', strstr( $response['body'], 'window._sharedData = ' ) );

			// Compatibility Check
			if ( version_compare( PHP_VERSION, '5.3.0', '>=' ) ) {
				$json = strstr( $json, '</script>', TRUE );
			} else {
				$json = substr( $json, 0, strpos( $json, '</script>' ) );
			}

			$json = rtrim( $json, ';' );

			// Function json_last_error() is not available before PHP * 5.3.0 version
			if ( function_exists( 'json_last_error' ) ) {
				( $results = json_decode( $json, TRUE ) ) && json_last_error() == JSON_ERROR_NONE;
			} else {
				$results = json_decode( $json, TRUE );
			}

			if ( $results && is_array( $results ) ) {
				if ( isset( $results['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'] ) ) {
					$entry_data = $results['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'];
				} else {
					$entry_data = array();
				}

				if ( empty( $entry_data ) ) {
					return esc_html__( 'No images found', 'moscow' );
				}

				foreach ( $entry_data as $current => $result ) {
					if ( $result['node']['__typename'] !== 'GraphImage' ) {
						$slice++;
						continue;
					}

					if ( $current >= $slice ) {
						break;
					}

					$image_data['code'] 			= $result['node']['shortcode'];
					$image_data['username'] 		= $username;
					$image_data['user_id'] 			= $result['node']['owner']['id'];
					$image_data['id'] 				= $result['node']['id'];
					$image_data['link'] 			= 'https://instagram.com/p/' . $result['node']['shortcode'];
					$image_data['popularity'] 		= (int) ( $result['node']['edge_media_to_comment']['count'] ) + ( $result['node']['edge_liked_by']['count'] );
					$image_data['timestamp'] 		= (float) $result['node']['taken_at_timestamp'];
					$image_data['url'] 				= $result['node']['display_url'];

					$image_data['url_medium'] 		= $result['node']['thumbnail_resources'][2]['src'];
					$image_data['url_thumbnail'] 	= $result['node']['thumbnail_resources'][1]['src'];

					$instaData[] = $image_data;
				}
			}

			if ( is_array( $instaData ) && ! empty( $instaData ) ) {
				set_transient( $option_name, $instaData, DAY_IN_SECONDS );
			}
		} else {
			return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'moscow' ) );
		}
	}

	return $instaData;

}