<?php

/**
 * Theme functions and definitions.
 * Fully compliant with WordPress coding standards.
 * -------------------------------------------------
 * @author akshitsethi
 * @link http://www.akshitsethi.com/
 * -------------------------------------------------
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


// Define constants for the theme.
// -------------------------------------------------

define( 'AS_THEME_NAME', 'moscow' );
define( 'AS_THEME_VERSION', '1.1.0' );
define( 'AS_THEME_PATH', get_template_directory() );
define( 'AS_THEME_URL', get_template_directory_uri() );


/**
 * Setup for the theme.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/setup.php';


/**
 * Load scripts and styles.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/scripts.php';


/**
 * 1. Required + recommended plugins.
 * 2. Unlimited sidebars.
 * 3. Register sidebar area.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/admin/plugins.php';			// 1
require_once AS_THEME_PATH . '/framework/admin/sidebars/main.php';		// 2
require_once AS_THEME_PATH . '/framework/admin/sidebars.php';			// 3


/**
 * -------------------------------------------------
 *  Customizer + Custom Controls
 * -------------------------------------------------
 *  Adding little magic to the customizer.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/admin/customizer.php';


/**
 * Custom template tags.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/template-tags.php';


/**
 * Custom functions.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/functions.php';


/**
 * Javascript localization options.
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/localize.php';


/**
 * 1. Admin selected settings.
 * 2. Body classes.
 * 3. Setup - Admin
 * -------------------------------------------------
 */

require_once AS_THEME_PATH . '/framework/include/settings.php';			// 1
require_once AS_THEME_PATH . '/framework/include/classes.php';			// 2


// Setup - Admin
// -------------------------------------------------

if ( is_admin() ) {

	require_once AS_THEME_PATH . '/framework/admin/setup.php'; 			// 3

	// REQUIRED : Update Checker
	// -------------------------------------------------

	if ( ! function_exists( 'moscow_update_checker' ) ) :
	function moscow_update_checker() {

		if ( is_plugin_active( 'as-required-plugin/as-required-plugin.php' ) ) {
			if ( defined( 'AS_RP_PATH' ) ) {
				if ( get_option( 'as_reg_' . AS_THEME_NAME ) ) {
					if ( file_exists( AS_RP_PATH . 'framework/admin/include/updater/plugin-update-checker.php' ) ) {
						require_once AS_RP_PATH . 'framework/admin/include/updater/plugin-update-checker.php';

						$as_rp_updates = Puc_v4_Factory::buildUpdateChecker( 'http://www.akshitsethi.com/api/products.php?slug=' . AS_THEME_NAME, __FILE__, ucfirst( AS_THEME_NAME ) );
					}
				}
			}
		}

	}
	add_action( 'admin_init', 'moscow_update_checker' );
	endif; // moscow_update_checker()

}